@@ -11,7 +11,6 @@
 #' @param range vector of harmonics on which to perform calibrate_reconstructions
 #' @param baseline1 \eqn{(x; y)} coordinates for the first point of the baseline
 #' @param baseline2 \eqn{(x; y)} coordinates for the second point of the baseline
-#' @param ... only used for the generic
 #' @return a ggplot object and the full list of intermediate results. See examples.
 #' @family calibration
 #' @name calibrate_reconstructions
@@ -43,12 +42,6 @@
 #' olea %>%
 #'     calibrate_reconstructions_dfourier(id=1)
 #'
-#' @rdname calibrate_reconstructions
-#' @export
-calibrate_reconstructions <- function(){
-  message("Deprecated, see ?calibrate_reconstructions")
-}
-
 #' @rdname calibrate_reconstructions
 #' @export
 calibrate_reconstructions_efourier <-
@@ -1597,7 +1590,7 @@ calibrate_harmonicpower_efourier <-
 
     # here we define the maximum nb.h, if missing
     if (missing(nb.h)){
-      nb.h <- floor(min(sapply(Out$coo, nrow))/2)
+      nb.h <- floor(min(coo_nb(Out)/2))-1
     }
     # we prepare the result matrix
     res <- matrix(nrow = length(id), ncol = (nb.h - drop))
@@ -1612,24 +1605,27 @@ calibrate_harmonicpower_efourier <-
     #res <- res[, -drop]
     # we calculte cumsum and percentages
     res <- t(apply(res, 1, function(x) cumsum(x) / sum(x))) * 100
-    # we ggplot
-    h_display <- which(apply(res, 2, median) >= 99)[1] + 2 # cosmectics
-    res %>% as.data.frame() %>% seq_along %>%
-      lapply(function(i) data.frame(Var1=rownames(res),
-                                    Var2=colnames(res)[i],
-                                    value=res[,i])) %>%
-      do.call("rbind", .) %>%
-      `colnames<-`(c("shp", "harm", "hp")) -> xx
-    if (length(id) > 2) {
-      gg <- ggplot(xx, aes_string(x="harm", y="hp")) + geom_boxplot() +
-        labs(x="Harmonic rank", y="Cumulative sum harmonic power") +
-        coord_cartesian(xlim=c(0.5, h_display+0.5))
-    } else {
-      gg <- ggplot(xx, aes_string(x="harm", y="hp")) + geom_point() +
-        labs(x="Harmonic rank", y="Cumulative sum harmonic power") +
-        coord_cartesian(xlim=c(0.5, h_display+0.5))
+    gg <- NA
+    if (plot){
+      # we ggplot
+      h_display <- which(apply(res, 2, median) >= 99)[1] + 2 # cosmectics
+      res %>% as.data.frame() %>% seq_along %>%
+        lapply(function(i) data.frame(Var1=rownames(res),
+                                      Var2=colnames(res)[i],
+                                      value=res[,i])) %>%
+        do.call("rbind", .) %>%
+        `colnames<-`(c("shp", "harm", "hp")) -> xx
+      if (length(id) > 2) {
+        gg <- ggplot(xx, aes_string(x="harm", y="hp")) + geom_boxplot() +
+          labs(x="Harmonic rank", y="Cumulative sum harmonic power") +
+          coord_cartesian(xlim=c(0.5, h_display+0.5))
+      } else {
+        gg <- ggplot(xx, aes_string(x="harm", y="hp")) + geom_point() +
+          labs(x="Harmonic rank", y="Cumulative sum harmonic power") +
+          coord_cartesian(xlim=c(0.5, h_display+0.5))
+        print(gg)
+      }
     }
-    if (plot) print(gg)
     # we calculate quantiles and add nice rowcolnames
     # also the median (independently of probs [0.5, etc]) since
     # thresh may change
@@ -1638,15 +1634,10 @@ calibrate_harmonicpower_efourier <-
     names(minh) <- paste0(thresh, "%")
     for (i in seq(along=thresh)){
       wi <- which(med.res > thresh[i])
-      minh[i] <- ifelse(length(wi)==0, NA, min(wi))}
-    minh <- minh+drop
-    # talk to me
-    if (.is_verbose()){
-      #     cat("\n$minh:\n")
-      print(minh)
+      minh[i] <- ifelse(length(wi)==0, NA, min(wi))
     }
-    # we return the full matrix, the ggplot and the thresholds
-    invisible(list(gg=gg, q=res, minh=minh))
+    minh <- minh+drop
+    return(list(gg=gg, q=res, minh=minh))
   }
 
 #' @rdname calibrate_harmonicpower
@@ -1708,12 +1699,9 @@ calibrate_harmonicpower_rfourier <-
       wi <- which(med.res > thresh[i])
       minh[i] <- ifelse(length(wi)==0, NA, min(wi))}
     minh <- minh+drop
-    # talk to me
-    if (.is_verbose()){
-      #     cat("\n$minh:\n")
-      print(minh)}
+
     # we return the full matrix, the ggplot and the thresholds
-    invisible(list(gg=gg, q=res, minh=minh))
+    return(list(gg=gg, q=res, minh=minh))
   }
 
 #' @rdname calibrate_harmonicpower
@@ -1775,12 +1763,8 @@ calibrate_harmonicpower_tfourier <-
       wi <- which(med.res > thresh[i])
       minh[i] <- ifelse(length(wi)==0, NA, min(wi))}
     minh <- minh+drop
-    # talk to me
-    if (.is_verbose()){
-      #     cat("\n$minh:\n")
-      print(minh)}
-    # we return the full matrix, the ggplot and the thresholds
-    invisible(list(gg=gg, q=res, minh=minh))
+
+    return(list(gg=gg, q=res, minh=minh))
   }
 
 #' @rdname calibrate_harmonicpower
@@ -1842,12 +1826,8 @@ calibrate_harmonicpower_sfourier <-
       wi <- which(med.res > thresh[i])
       minh[i] <- ifelse(length(wi)==0, NA, min(wi))}
     minh <- minh+drop
-    # talk to me
-    if (.is_verbose()){
-      #     cat("\n$minh:\n")
-      print(minh)}
-    # we return the full matrix, the ggplot and the thresholds
-    invisible(list(gg=gg, q=res, minh=minh))
+
+    return(list(gg=gg, q=res, minh=minh))
   }
 
 
@@ -1910,12 +1890,8 @@ calibrate_harmonicpower_dfourier <-
       wi <- which(med.res > thresh[i])
       minh[i] <- ifelse(length(wi)==0, NA, min(wi))}
     minh <- minh+drop
-    # talk to me
-    if (.is_verbose()){
-      #     cat("\n$minh:\n")
-      print(minh)}
-    # we return the full matrix, the ggplot and the thresholds
-    invisible(list(gg=gg, q=res, minh=minh))
+
+    return(list(gg=gg, q=res, minh=minh))
   }
 
 # 4. calibrate_r2 ----------------
@@ -1990,12 +1966,9 @@ calibrate_r2_opoly <- function(Opn, id = 1:length(Opn),
     wi <- which(med.res > thresh[i])
     minh[i] <- ifelse(length(wi)==0, NA, min(wi))}
   mind <- minh
-  # talk to me
-  if (.is_verbose()){
-    #     cat("\n$minh:\n")
-    print(mind)}
-  # we return the full matrix, the ggplot and the thresholds
-  invisible(list(gg=gg, q=res, mind=mind))
+
+  return(list(gg=gg, q=res, mind=mind))
+
 }
 
 #' @rdname calibrate_r2
@@ -2039,10 +2012,5 @@ calibrate_r2_npoly <- function(Opn, id = 1:length(Opn),
     wi <- which(med.res > thresh[i])
     minh[i] <- ifelse(length(wi)==0, NA, min(wi))}
   mind <- minh
-  # talk to me
-  if (.is_verbose()){
-    #     cat("\n$minh:\n")
-    print(mind)}
-  # we return the full matrix, the ggplot and the thresholds
-  invisible(list(gg=gg, q=res, mind=mind))
+  return(list(gg=gg, q=res, mind=mind))
 }
