@@ -8,7 +8,7 @@
 #' @param id1 id of the 1st row
 #' @param id2 id of the 2nd row
 #' @note On Out objects, we first \link{get_ldk}.
-#' @seealso if you want all pairwise combinations, see \link{truss}
+#' @seealso if you want all pairwise combinations, see \link{coo_truss}
 #' @examples
 #' # single shape
 #' d(wings[1], 1, 4)
@@ -54,22 +54,18 @@ d.Out <- function(x, id1, id2){
 #' @return a \link{TraCoe} object, or a raw data.frame
 #' @family premodern
 #' @examples
-#' # lets write a custom function
-#' coo_ellipse_area <- function(x){
-#'   prod(coo_lw(x))*pi
-#' }
-#' bm <- measure(bot, coo_area, coo_perim, coo_ellipse_area)
+#' bm <- measure(bot, coo_area, coo_perim)
 #' bm
 #' bm$coe
 #'
 #' # how to use arguments, eg with the d() function
 #' measure(wings, coo_area, d(1, 3), d(4, 5))
 #'
-#' # alternatively
-#' measure(bot$coo, coo_area, coo_perim, coo_ellipse_area)
+#' # alternatively, to get a data_frame
+#' measure(bot$coo, coo_area, coo_perim)
 #'
-#' # and also
-#' measure(bot[1], coo_area, coo_perim, coo_ellipse_area)
+#' # and also, to get a data_frame (one row)
+#' measure(bot[1], coo_area, coo_perim)
 #' @export
 measure <- function(x, ...){
   UseMethod("measure")
@@ -94,7 +90,7 @@ measure.list <- function(x, ...){
   for (i in seq_along(funs)){
     l[[i]] <- sapply(x, funs[i])
   }
-  l %>% as.data.frame() %>% return()
+  data.frame(l) %>% dplyr::as_data_frame() %>% return
 }
 
 #' @export
@@ -113,9 +109,10 @@ measure.Coo <- function(x, ...){
       l[[i]] <- sapply(x$coo, funs[i])
     }
   }
-  coe <- l %>% as.data.frame()
-  TraCoe(coe = l %>% as.data.frame,
-         fac = x$fac)
+  coe <- data.frame(l) %>% dplyr::as_data_frame()
+  fac <- x$fac
+  TraCoe(coe = coe,
+         fac = fac)
 }
 
 # dirty attemps at NSE-ishing
@@ -133,21 +130,20 @@ measure_nse <- function(ch){
 
 #' Truss measurement
 #'
-#' A method to calculate on shapes or on Coo truss measurements,
-#' which is all pairwise combinations of euclidean distances
+#' A method to calculate on shapes or on [Coo] truss measurements,
+#' that is all pairwise combinations of euclidean distances
 #' @param x a shape or an Ldk object
 #' @return a named numeric or matrix
 #' @note Mainly implemented for historical/didactical reasons.
 #' @family premodern
 #' @examples
 #' # example on a single shape
-#' data(shapes)
 #' cat <- coo_sample(shapes[4], 6)
-#' truss(cat)
+#' coo_truss(cat)
 #'
 #' # example on wings dataset
-#' data(wings)
-#' tx <- truss(wings)
+
+#' tx <- coo_truss(wings)
 #' dim(tx)
 #' # we normalize and plot an heatmap
 #' txn <- apply(tx$coe, 2, .normalize)
@@ -156,21 +152,25 @@ measure_nse <- function(ch){
 #' txp <- PCA(tx, scale. = TRUE, center=TRUE, fac=wings$fac)
 #' plot(txp, 1)
 #' @export
-truss <- function(x){
-  UseMethod("truss")
+coo_truss <- function(x){
+  UseMethod("coo_truss")
 }
 
 #' @export
-truss.default <- function(x){
+coo_truss.default <- function(x){
   res <- as.numeric(dist(x))
-  names(res) <- apply(combn(1:nrow(x), 2), 2, paste, collapse="-")
+  names(res) <- apply(utils::combn(1:nrow(x), 2), 2, paste, collapse="-")
   return(res)
 }
 
 #' @export
-truss.Ldk <- function(x){
-  TraCoe(coe=x$coo %>% sapply(truss) %>% t(),
+coo_truss.Coo <- function(x){
+  .check(length(unique(coo_nb(x)))==1,
+         "all shapes must have the same number of coordinates. See ?coo_sample")
+  TraCoe(coe=x$coo %>% sapply(coo_truss) %>% t(),
          fac=x$fac)
 }
 
 
+
+
